@@ -394,7 +394,7 @@ class Eniam():
         {valence_rules_str}
         """
 
-    def dom(self, input_text):
+    def dom(self, input_text, silent=True):
         p = run_domparser(["--no-sem", "--no-def-cat"], PIPE, PIPE, self.lexicon_content, self.valence_content)
         q_out = Queue()
         q_err = Queue()
@@ -480,7 +480,8 @@ class Eniam():
             except Empty:
                 err_line = ""
             if len(err_line) > 0:
-                print(err_line.replace("\n", "").replace("\r", ""))
+                if not silent:
+                    print(err_line.replace("\n", "").replace("\r", ""))
                 #collect_err = True
                 #output_err.append(err_line)
                 #break
